% Examples of emiCCA
% Notice: Before running this m file, please adding emiCCA toolbox path to matlab.
% -----------------------------------
%   Author: Li Dong
%   Li_dong729@163.com
%   Reference:
%   Li Dong, Yangsong Zhang, Rui Zhang, Xingxing Zhang, Diankun Gong, Pedro A.
%      Valdes-Sosa, Peng Xu, Cheng Luo, Dezhong Yao.Characterizing nonlinear relationships 
%      in functional imaging data using eigenspace maximal information canonical correlation analysis (emiCCA).
%      Neuroimage,2015,Accepted.
%   $Date: 2015/1/16
% =========================================================================
% Example 1: Linear situation

clear all;clc
load carbig;
X = [Displacement Horsepower Weight Acceleration MPG];
nans = sum(isnan(X),2) > 0;
[A1,B1,r1,U1,V1] = emiCCA(X(~nans,1:3),X(~nans,4:5));
[A2,B2,r2,U2,V2] = canoncorr(X(~nans,1:3),X(~nans,4:5));

figure;
subplot(1,2,1);
plot(U1(:,1),V1(:,1),'.');
xlabel('U1');
ylabel('V1');
title(['MIEC = ',num2str(r1(1))]);

subplot(1,2,2)
plot(U2(:,1),V2(:,1),'.');
xlabel('U2');
ylabel('V2');
title(['Canonical Coeeficient = ',num2str(r2(1))]);
% -------------------------------------------------------------------------
% Example 2: nonlinear situation (cosinusoidal)

clear all ;clc
% -------------------------
% get path of emiCCA function
emiCCApath = which('emiCCA.m');
emiCCApath = emiCCApath(1:end-length('emiCCA.m'));
% --------------------------
n = 500; % length of data samples
p1 = 6;  % X dimensions
p2 = 4;  % Y dimensions
e = 0.05; % IID noise
x = 2*rand(10000,p1+p2)-1; % [-1 1]
load ([emiCCApath,'pro_index\Pro_index_MIC_5000_500.mat']) % Probability of MIC coefficients generated from null distribution.
P = 0.05; % Threshold of MIC p-value.
flag = 2; % flag = 1 -> uncorrected; flag = 2 -> FDR

X = x(1:n,1:p1);
Y = x(1:n,p1+1:p1+p2);
Y(:,1) = cos(2*pi*X(:,1));
% add noise
X1 = X + e * randn(size(X));
Y1 = Y + e * randn(size(Y));

[A1,B1,r1,U1,V1,stats_1] = emiCCA(X1,Y1,Pro_index,flag,P);
[A2,B2,r2,U2,V2,stats_2] = canoncorr(X1,Y1);

% --------------------------
figure;
index = find(r1 == max(r1));
subplot(1,2,1);
plot(U1(:,index(1)),V1(:,index(1)),'.');
xlabel('U1');
ylabel('V1');
title(['emiCCA: MIEC = ',num2str(r1(index(1))),' p = ',num2str(stats_1.P(1,index(1)))]);

subplot(1,2,2)
plot(U2(:,1),V2(:,1),'.');
xlabel('U2');
ylabel('V2');
title(['CCA: Canonical Coeeficient = ',num2str(r2(1)),' p = ',num2str(stats_1.P(1,1))]);
% -------------------------------------------------------------------------
