% =========================================================================
%          Generate NULL distribution of MIC based on random data
% =========================================================================
% Notice: Before running this m file, please adding emiCCA toolbox path to matlab.
% Step by step: 
% [1] set the parameters: Nt (the random number) and L (length of data/ the
%     sample size of data).
% [2] run this m file.
% Reference: 
% Li Dong, Yangsong Zhang, Rui Zhang, Xingxing Zhang, Diankun Gong, Pedro A.
%      Valdes-Sosa, Peng Xu, Cheng Luo, Dezhong Yao.Characterizing nonlinear relationships 
%      in functional imaging data using eigenspace maximal information canonical correlation analysis (emiCCA).
%      Neuroimage,2015,Accepted.
% Copy right is belong to Li Dong: Li_dong729@163.com
% $Date: 2015/1/16
% -------------------------------------------------------------------------
clear all;clc
Nt = 5000;  % the random number.
rand_results = zeros(6,Nt);
L = [20:20:100 150:50:1000 1200:200:2000]; % length of data;
% -------------------------
% get path of emiCCA function (to find MINE.jar)
emiCCApath = which('emiCCA.m');
emiCCApath = emiCCApath(1:end-length('emiCCA.m'));
% --------------------------
for j = 1:length(L)
    L1 = L(j);
    % =========================================================================
    % generate null distribution
    % ------------------ generate rand data ---------------
    for i = 1:Nt
        % X = rand(2,1428);
        x1 = randperm(L1);
        x2 = randperm(L1);
        X = [x1;x2];
        % ------ plot check ----
        %     figure;
        %     plot(X(1,:),X(2,:),'.b');
        % -----------------------
        M1 = [(1:2)' X];
        rand_name = [emiCCApath,'temp_data\rand_time.csv'];
        csvwrite(rand_name,M1);
        % delete('rand_time.csv,allpairs,cv=0.0,B=n^0.6,Results.csv');
        % fprintf('\n%d',j);
        
        % -------------------- calculate MIC ---------------
        % Using MINE to calsulate MIC bewteen tiemcouses.
        command_1 =['java -jar ',[emiCCApath,'MINE.jar '],rand_name,...
                    ' -allPairs cv=0 exp=0.55 c=5'];
        system(command_1);
        
        % ------------------- save results ---------------
        name = [emiCCApath,'temp_data\rand_time.csv,allpairs,cv=0.0,B=n^0.55,Results.csv'];
        
        fid = fopen(name);
        if fid == (-1)
            error('MATLAB:dlmwrite:FileOpenFailure',...
                'Could not open file %s', name);
            break;
        end
        
        a1 = textscan(fid,'%s');
        y = str2num(a1{1,1}{11,1});
        rand_results(:,i) = y(1,3:8);
        fclose(fid);

        fopen('all'); % List all open files
        fclose('all'); % Close all open files
    end;
    % ------- save ------
    % save
    name1 = [emiCCApath,'temp_data\MIC_null_distri_',num2str(Nt),'_',num2str(L1),'.mat'];
    save(name1,'rand_results');
    % =========================================================================
    % generate P probability index
    data = rand_results(1,1:5000); % MIC rand data
    % ------------- Bins ------------
    hist_ind = 0:0.0001:1;
    % ----- Compute histogram and plot-------
    data_hist  = ksdensity (data, hist_ind);% [Y, I] = max(data_hist);
    figure;
    subplot(1,2,1)
    hist(data, hist_ind);
    axis([0 1 0 40]);
    title('Hist of null distribution(5000 times)')
    subplot(1,2,2)
    ksdensity (data, hist_ind,'kernel','normal','function','pdf');
    axis([0 1 0 20]);
    title('Density of null distribution(5000 times)')
    
    % ----------- Compute probability index --------
    [Hp,xi]= ksdensity (data(1,:),hist_ind,'kernel','normal','function','cdf');
    Pro_index = ([1-Hp;xi])';
    % ------------ save -----------
    % save
    name2 = [emiCCApath,'pro_index\Pro_index_MIC_',num2str(Nt),'_',num2str(L1),'.mat'];
    save(name2,'Pro_index');

    fprintf('\n%d',j);
end;